.. meta::
   :description: Reference documentation responsible AI toolbox PyTorch loss functions

.. _losses-reference:

######
Losses
######

The rAI-toolbox provides implementations of loss functions that are not already provided
by PyTorch (e.g., `torch.nn.CrossEntropyLoss`).

.. currentmodule:: rai_toolbox.losses

.. autosummary::
   :toctree: generated/

   jensen_shannon_divergence
